cashbook

package
v0.0.0-...-2afdb13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: GPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithAcceptApplicationJSON

func WithAcceptApplicationJSON(r *runtime.ClientOperation)

WithAcceptApplicationJSON sets the Accept header to "application/json".

func WithAcceptApplicationXML

func WithAcceptApplicationXML(r *runtime.ClientOperation)

WithAcceptApplicationXML sets the Accept header to "application/xml".

func WithAcceptTextJSON

func WithAcceptTextJSON(r *runtime.ClientOperation)

WithAcceptTextJSON sets the Accept header to "text/json".

func WithAcceptTextXML

func WithAcceptTextXML(r *runtime.ClientOperation)

WithAcceptTextXML sets the Accept header to "text/xml".

func WithContentTypeApplicationJSON

func WithContentTypeApplicationJSON(r *runtime.ClientOperation)

WithContentTypeApplicationJSON sets the Content-Type header to "application/json".

func WithContentTypeApplicationXML

func WithContentTypeApplicationXML(r *runtime.ClientOperation)

WithContentTypeApplicationXML sets the Content-Type header to "application/xml".

func WithContentTypeApplicationxWwwFormUrlencoded

func WithContentTypeApplicationxWwwFormUrlencoded(r *runtime.ClientOperation)

WithContentTypeApplicationxWwwFormUrlencoded sets the Content-Type header to "application/x-www-form-urlencoded".

func WithContentTypeTextJSON

func WithContentTypeTextJSON(r *runtime.ClientOperation)

WithContentTypeTextJSON sets the Content-Type header to "text/json".

func WithContentTypeTextXML

func WithContentTypeTextXML(r *runtime.ClientOperation)

WithContentTypeTextXML sets the Content-Type header to "text/xml".

Types

type CashbookCloseCashbookOK

type CashbookCloseCashbookOK struct {
}

CashbookCloseCashbookOK describes a response with status code 200, with default header values.

Close the active cash book, initialization of a new one is required to add new entries

func NewCashbookCloseCashbookOK

func NewCashbookCloseCashbookOK() *CashbookCloseCashbookOK

NewCashbookCloseCashbookOK creates a CashbookCloseCashbookOK with default headers values

func (*CashbookCloseCashbookOK) Code

func (o *CashbookCloseCashbookOK) Code() int

Code gets the status code for the cashbook close cashbook o k response

func (*CashbookCloseCashbookOK) Error

func (o *CashbookCloseCashbookOK) Error() string

func (*CashbookCloseCashbookOK) IsClientError

func (o *CashbookCloseCashbookOK) IsClientError() bool

IsClientError returns true when this cashbook close cashbook o k response has a 4xx status code

func (*CashbookCloseCashbookOK) IsCode

func (o *CashbookCloseCashbookOK) IsCode(code int) bool

IsCode returns true when this cashbook close cashbook o k response a status code equal to that given

func (*CashbookCloseCashbookOK) IsRedirect

func (o *CashbookCloseCashbookOK) IsRedirect() bool

IsRedirect returns true when this cashbook close cashbook o k response has a 3xx status code

func (*CashbookCloseCashbookOK) IsServerError

func (o *CashbookCloseCashbookOK) IsServerError() bool

IsServerError returns true when this cashbook close cashbook o k response has a 5xx status code

func (*CashbookCloseCashbookOK) IsSuccess

func (o *CashbookCloseCashbookOK) IsSuccess() bool

IsSuccess returns true when this cashbook close cashbook o k response has a 2xx status code

func (*CashbookCloseCashbookOK) String

func (o *CashbookCloseCashbookOK) String() string

type CashbookCloseCashbookParams

type CashbookCloseCashbookParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookCloseCashbookParams contains all the parameters to send to the API endpoint

for the cashbook close cashbook operation.

Typically these are written to a http.Request.

func NewCashbookCloseCashbookParams

func NewCashbookCloseCashbookParams() *CashbookCloseCashbookParams

NewCashbookCloseCashbookParams creates a new CashbookCloseCashbookParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookCloseCashbookParamsWithContext

func NewCashbookCloseCashbookParamsWithContext(ctx context.Context) *CashbookCloseCashbookParams

NewCashbookCloseCashbookParamsWithContext creates a new CashbookCloseCashbookParams object with the ability to set a context for a request.

func NewCashbookCloseCashbookParamsWithHTTPClient

func NewCashbookCloseCashbookParamsWithHTTPClient(client *http.Client) *CashbookCloseCashbookParams

NewCashbookCloseCashbookParamsWithHTTPClient creates a new CashbookCloseCashbookParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookCloseCashbookParamsWithTimeout

func NewCashbookCloseCashbookParamsWithTimeout(timeout time.Duration) *CashbookCloseCashbookParams

NewCashbookCloseCashbookParamsWithTimeout creates a new CashbookCloseCashbookParams object with the ability to set a timeout on a request.

func (*CashbookCloseCashbookParams) SetContext

func (o *CashbookCloseCashbookParams) SetContext(ctx context.Context)

SetContext adds the context to the cashbook close cashbook params

func (*CashbookCloseCashbookParams) SetDefaults

func (o *CashbookCloseCashbookParams) SetDefaults()

SetDefaults hydrates default values in the cashbook close cashbook params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookCloseCashbookParams) SetHTTPClient

func (o *CashbookCloseCashbookParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook close cashbook params

func (*CashbookCloseCashbookParams) SetTimeout

func (o *CashbookCloseCashbookParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook close cashbook params

func (*CashbookCloseCashbookParams) WithContext

WithContext adds the context to the cashbook close cashbook params

func (*CashbookCloseCashbookParams) WithDefaults

WithDefaults hydrates default values in the cashbook close cashbook params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookCloseCashbookParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the cashbook close cashbook params

func (*CashbookCloseCashbookParams) WithTimeout

WithTimeout adds the timeout to the cashbook close cashbook params

func (*CashbookCloseCashbookParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookCloseCashbookReader

type CashbookCloseCashbookReader struct {
	// contains filtered or unexported fields
}

CashbookCloseCashbookReader is a Reader for the CashbookCloseCashbook structure.

func (*CashbookCloseCashbookReader) ReadResponse

func (o *CashbookCloseCashbookReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CashbookGetCashbookEntriesOK

type CashbookGetCashbookEntriesOK struct {
	Payload *model.PageResultCashbookEntry
}

CashbookGetCashbookEntriesOK describes a response with status code 200, with default header values.

Get an overview of all the entries in the cash book

func NewCashbookGetCashbookEntriesOK

func NewCashbookGetCashbookEntriesOK() *CashbookGetCashbookEntriesOK

NewCashbookGetCashbookEntriesOK creates a CashbookGetCashbookEntriesOK with default headers values

func (*CashbookGetCashbookEntriesOK) Code

Code gets the status code for the cashbook get cashbook entries o k response

func (*CashbookGetCashbookEntriesOK) Error

func (*CashbookGetCashbookEntriesOK) GetPayload

func (*CashbookGetCashbookEntriesOK) IsClientError

func (o *CashbookGetCashbookEntriesOK) IsClientError() bool

IsClientError returns true when this cashbook get cashbook entries o k response has a 4xx status code

func (*CashbookGetCashbookEntriesOK) IsCode

func (o *CashbookGetCashbookEntriesOK) IsCode(code int) bool

IsCode returns true when this cashbook get cashbook entries o k response a status code equal to that given

func (*CashbookGetCashbookEntriesOK) IsRedirect

func (o *CashbookGetCashbookEntriesOK) IsRedirect() bool

IsRedirect returns true when this cashbook get cashbook entries o k response has a 3xx status code

func (*CashbookGetCashbookEntriesOK) IsServerError

func (o *CashbookGetCashbookEntriesOK) IsServerError() bool

IsServerError returns true when this cashbook get cashbook entries o k response has a 5xx status code

func (*CashbookGetCashbookEntriesOK) IsSuccess

func (o *CashbookGetCashbookEntriesOK) IsSuccess() bool

IsSuccess returns true when this cashbook get cashbook entries o k response has a 2xx status code

func (*CashbookGetCashbookEntriesOK) String

type CashbookGetCashbookEntriesParams

type CashbookGetCashbookEntriesParams struct {

	// FullTextSearch.
	FullTextSearch *string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookGetCashbookEntriesParams contains all the parameters to send to the API endpoint

for the cashbook get cashbook entries operation.

Typically these are written to a http.Request.

func NewCashbookGetCashbookEntriesParams

func NewCashbookGetCashbookEntriesParams() *CashbookGetCashbookEntriesParams

NewCashbookGetCashbookEntriesParams creates a new CashbookGetCashbookEntriesParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookGetCashbookEntriesParamsWithContext

func NewCashbookGetCashbookEntriesParamsWithContext(ctx context.Context) *CashbookGetCashbookEntriesParams

NewCashbookGetCashbookEntriesParamsWithContext creates a new CashbookGetCashbookEntriesParams object with the ability to set a context for a request.

func NewCashbookGetCashbookEntriesParamsWithHTTPClient

func NewCashbookGetCashbookEntriesParamsWithHTTPClient(client *http.Client) *CashbookGetCashbookEntriesParams

NewCashbookGetCashbookEntriesParamsWithHTTPClient creates a new CashbookGetCashbookEntriesParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookGetCashbookEntriesParamsWithTimeout

func NewCashbookGetCashbookEntriesParamsWithTimeout(timeout time.Duration) *CashbookGetCashbookEntriesParams

NewCashbookGetCashbookEntriesParamsWithTimeout creates a new CashbookGetCashbookEntriesParams object with the ability to set a timeout on a request.

func (*CashbookGetCashbookEntriesParams) SetContext

SetContext adds the context to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) SetDefaults

func (o *CashbookGetCashbookEntriesParams) SetDefaults()

SetDefaults hydrates default values in the cashbook get cashbook entries params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbookEntriesParams) SetFullTextSearch

func (o *CashbookGetCashbookEntriesParams) SetFullTextSearch(fullTextSearch *string)

SetFullTextSearch adds the fullTextSearch to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) SetHTTPClient

func (o *CashbookGetCashbookEntriesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) SetTimeout

func (o *CashbookGetCashbookEntriesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) WithContext

WithContext adds the context to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) WithDefaults

WithDefaults hydrates default values in the cashbook get cashbook entries params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbookEntriesParams) WithFullTextSearch

func (o *CashbookGetCashbookEntriesParams) WithFullTextSearch(fullTextSearch *string) *CashbookGetCashbookEntriesParams

WithFullTextSearch adds the fullTextSearch to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) WithTimeout

WithTimeout adds the timeout to the cashbook get cashbook entries params

func (*CashbookGetCashbookEntriesParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookGetCashbookEntriesReader

type CashbookGetCashbookEntriesReader struct {
	// contains filtered or unexported fields
}

CashbookGetCashbookEntriesReader is a Reader for the CashbookGetCashbookEntries structure.

func (*CashbookGetCashbookEntriesReader) ReadResponse

func (o *CashbookGetCashbookEntriesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CashbookGetCashbookHistoryOK

type CashbookGetCashbookHistoryOK struct {
	Payload *model.PageResultCashbookEntry
}

CashbookGetCashbookHistoryOK describes a response with status code 200, with default header values.

Get an overview of all the entries in the cash book

func NewCashbookGetCashbookHistoryOK

func NewCashbookGetCashbookHistoryOK() *CashbookGetCashbookHistoryOK

NewCashbookGetCashbookHistoryOK creates a CashbookGetCashbookHistoryOK with default headers values

func (*CashbookGetCashbookHistoryOK) Code

Code gets the status code for the cashbook get cashbook history o k response

func (*CashbookGetCashbookHistoryOK) Error

func (*CashbookGetCashbookHistoryOK) GetPayload

func (*CashbookGetCashbookHistoryOK) IsClientError

func (o *CashbookGetCashbookHistoryOK) IsClientError() bool

IsClientError returns true when this cashbook get cashbook history o k response has a 4xx status code

func (*CashbookGetCashbookHistoryOK) IsCode

func (o *CashbookGetCashbookHistoryOK) IsCode(code int) bool

IsCode returns true when this cashbook get cashbook history o k response a status code equal to that given

func (*CashbookGetCashbookHistoryOK) IsRedirect

func (o *CashbookGetCashbookHistoryOK) IsRedirect() bool

IsRedirect returns true when this cashbook get cashbook history o k response has a 3xx status code

func (*CashbookGetCashbookHistoryOK) IsServerError

func (o *CashbookGetCashbookHistoryOK) IsServerError() bool

IsServerError returns true when this cashbook get cashbook history o k response has a 5xx status code

func (*CashbookGetCashbookHistoryOK) IsSuccess

func (o *CashbookGetCashbookHistoryOK) IsSuccess() bool

IsSuccess returns true when this cashbook get cashbook history o k response has a 2xx status code

func (*CashbookGetCashbookHistoryOK) String

type CashbookGetCashbookHistoryParams

type CashbookGetCashbookHistoryParams struct {

	// CashbookID.
	//
	// Format: int32
	CashbookID int32

	// FullTextSearch.
	FullTextSearch *string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookGetCashbookHistoryParams contains all the parameters to send to the API endpoint

for the cashbook get cashbook history operation.

Typically these are written to a http.Request.

func NewCashbookGetCashbookHistoryParams

func NewCashbookGetCashbookHistoryParams() *CashbookGetCashbookHistoryParams

NewCashbookGetCashbookHistoryParams creates a new CashbookGetCashbookHistoryParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookGetCashbookHistoryParamsWithContext

func NewCashbookGetCashbookHistoryParamsWithContext(ctx context.Context) *CashbookGetCashbookHistoryParams

NewCashbookGetCashbookHistoryParamsWithContext creates a new CashbookGetCashbookHistoryParams object with the ability to set a context for a request.

func NewCashbookGetCashbookHistoryParamsWithHTTPClient

func NewCashbookGetCashbookHistoryParamsWithHTTPClient(client *http.Client) *CashbookGetCashbookHistoryParams

NewCashbookGetCashbookHistoryParamsWithHTTPClient creates a new CashbookGetCashbookHistoryParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookGetCashbookHistoryParamsWithTimeout

func NewCashbookGetCashbookHistoryParamsWithTimeout(timeout time.Duration) *CashbookGetCashbookHistoryParams

NewCashbookGetCashbookHistoryParamsWithTimeout creates a new CashbookGetCashbookHistoryParams object with the ability to set a timeout on a request.

func (*CashbookGetCashbookHistoryParams) SetCashbookID

func (o *CashbookGetCashbookHistoryParams) SetCashbookID(cashbookID int32)

SetCashbookID adds the cashbookId to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) SetContext

SetContext adds the context to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) SetDefaults

func (o *CashbookGetCashbookHistoryParams) SetDefaults()

SetDefaults hydrates default values in the cashbook get cashbook history params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbookHistoryParams) SetFullTextSearch

func (o *CashbookGetCashbookHistoryParams) SetFullTextSearch(fullTextSearch *string)

SetFullTextSearch adds the fullTextSearch to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) SetHTTPClient

func (o *CashbookGetCashbookHistoryParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) SetTimeout

func (o *CashbookGetCashbookHistoryParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) WithCashbookID

WithCashbookID adds the cashbookID to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) WithContext

WithContext adds the context to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) WithDefaults

WithDefaults hydrates default values in the cashbook get cashbook history params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbookHistoryParams) WithFullTextSearch

func (o *CashbookGetCashbookHistoryParams) WithFullTextSearch(fullTextSearch *string) *CashbookGetCashbookHistoryParams

WithFullTextSearch adds the fullTextSearch to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) WithTimeout

WithTimeout adds the timeout to the cashbook get cashbook history params

func (*CashbookGetCashbookHistoryParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookGetCashbookHistoryReader

type CashbookGetCashbookHistoryReader struct {
	// contains filtered or unexported fields
}

CashbookGetCashbookHistoryReader is a Reader for the CashbookGetCashbookHistory structure.

func (*CashbookGetCashbookHistoryReader) ReadResponse

func (o *CashbookGetCashbookHistoryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CashbookGetCashbookOK

type CashbookGetCashbookOK struct {
	Payload *model.CashbookModel
}

CashbookGetCashbookOK describes a response with status code 200, with default header values.

Get information about the current active cash book

func NewCashbookGetCashbookOK

func NewCashbookGetCashbookOK() *CashbookGetCashbookOK

NewCashbookGetCashbookOK creates a CashbookGetCashbookOK with default headers values

func (*CashbookGetCashbookOK) Code

func (o *CashbookGetCashbookOK) Code() int

Code gets the status code for the cashbook get cashbook o k response

func (*CashbookGetCashbookOK) Error

func (o *CashbookGetCashbookOK) Error() string

func (*CashbookGetCashbookOK) GetPayload

func (o *CashbookGetCashbookOK) GetPayload() *model.CashbookModel

func (*CashbookGetCashbookOK) IsClientError

func (o *CashbookGetCashbookOK) IsClientError() bool

IsClientError returns true when this cashbook get cashbook o k response has a 4xx status code

func (*CashbookGetCashbookOK) IsCode

func (o *CashbookGetCashbookOK) IsCode(code int) bool

IsCode returns true when this cashbook get cashbook o k response a status code equal to that given

func (*CashbookGetCashbookOK) IsRedirect

func (o *CashbookGetCashbookOK) IsRedirect() bool

IsRedirect returns true when this cashbook get cashbook o k response has a 3xx status code

func (*CashbookGetCashbookOK) IsServerError

func (o *CashbookGetCashbookOK) IsServerError() bool

IsServerError returns true when this cashbook get cashbook o k response has a 5xx status code

func (*CashbookGetCashbookOK) IsSuccess

func (o *CashbookGetCashbookOK) IsSuccess() bool

IsSuccess returns true when this cashbook get cashbook o k response has a 2xx status code

func (*CashbookGetCashbookOK) String

func (o *CashbookGetCashbookOK) String() string

type CashbookGetCashbookParams

type CashbookGetCashbookParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookGetCashbookParams contains all the parameters to send to the API endpoint

for the cashbook get cashbook operation.

Typically these are written to a http.Request.

func NewCashbookGetCashbookParams

func NewCashbookGetCashbookParams() *CashbookGetCashbookParams

NewCashbookGetCashbookParams creates a new CashbookGetCashbookParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookGetCashbookParamsWithContext

func NewCashbookGetCashbookParamsWithContext(ctx context.Context) *CashbookGetCashbookParams

NewCashbookGetCashbookParamsWithContext creates a new CashbookGetCashbookParams object with the ability to set a context for a request.

func NewCashbookGetCashbookParamsWithHTTPClient

func NewCashbookGetCashbookParamsWithHTTPClient(client *http.Client) *CashbookGetCashbookParams

NewCashbookGetCashbookParamsWithHTTPClient creates a new CashbookGetCashbookParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookGetCashbookParamsWithTimeout

func NewCashbookGetCashbookParamsWithTimeout(timeout time.Duration) *CashbookGetCashbookParams

NewCashbookGetCashbookParamsWithTimeout creates a new CashbookGetCashbookParams object with the ability to set a timeout on a request.

func (*CashbookGetCashbookParams) SetContext

func (o *CashbookGetCashbookParams) SetContext(ctx context.Context)

SetContext adds the context to the cashbook get cashbook params

func (*CashbookGetCashbookParams) SetDefaults

func (o *CashbookGetCashbookParams) SetDefaults()

SetDefaults hydrates default values in the cashbook get cashbook params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbookParams) SetHTTPClient

func (o *CashbookGetCashbookParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook get cashbook params

func (*CashbookGetCashbookParams) SetTimeout

func (o *CashbookGetCashbookParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook get cashbook params

func (*CashbookGetCashbookParams) WithContext

WithContext adds the context to the cashbook get cashbook params

func (*CashbookGetCashbookParams) WithDefaults

WithDefaults hydrates default values in the cashbook get cashbook params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbookParams) WithHTTPClient

func (o *CashbookGetCashbookParams) WithHTTPClient(client *http.Client) *CashbookGetCashbookParams

WithHTTPClient adds the HTTPClient to the cashbook get cashbook params

func (*CashbookGetCashbookParams) WithTimeout

WithTimeout adds the timeout to the cashbook get cashbook params

func (*CashbookGetCashbookParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookGetCashbookReader

type CashbookGetCashbookReader struct {
	// contains filtered or unexported fields
}

CashbookGetCashbookReader is a Reader for the CashbookGetCashbook structure.

func (*CashbookGetCashbookReader) ReadResponse

func (o *CashbookGetCashbookReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CashbookGetCashbooksOK

type CashbookGetCashbooksOK struct {
	Payload []*model.CashbookModel
}

CashbookGetCashbooksOK describes a response with status code 200, with default header values.

Get an overview of all the closed cash books

func NewCashbookGetCashbooksOK

func NewCashbookGetCashbooksOK() *CashbookGetCashbooksOK

NewCashbookGetCashbooksOK creates a CashbookGetCashbooksOK with default headers values

func (*CashbookGetCashbooksOK) Code

func (o *CashbookGetCashbooksOK) Code() int

Code gets the status code for the cashbook get cashbooks o k response

func (*CashbookGetCashbooksOK) Error

func (o *CashbookGetCashbooksOK) Error() string

func (*CashbookGetCashbooksOK) GetPayload

func (o *CashbookGetCashbooksOK) GetPayload() []*model.CashbookModel

func (*CashbookGetCashbooksOK) IsClientError

func (o *CashbookGetCashbooksOK) IsClientError() bool

IsClientError returns true when this cashbook get cashbooks o k response has a 4xx status code

func (*CashbookGetCashbooksOK) IsCode

func (o *CashbookGetCashbooksOK) IsCode(code int) bool

IsCode returns true when this cashbook get cashbooks o k response a status code equal to that given

func (*CashbookGetCashbooksOK) IsRedirect

func (o *CashbookGetCashbooksOK) IsRedirect() bool

IsRedirect returns true when this cashbook get cashbooks o k response has a 3xx status code

func (*CashbookGetCashbooksOK) IsServerError

func (o *CashbookGetCashbooksOK) IsServerError() bool

IsServerError returns true when this cashbook get cashbooks o k response has a 5xx status code

func (*CashbookGetCashbooksOK) IsSuccess

func (o *CashbookGetCashbooksOK) IsSuccess() bool

IsSuccess returns true when this cashbook get cashbooks o k response has a 2xx status code

func (*CashbookGetCashbooksOK) String

func (o *CashbookGetCashbooksOK) String() string

type CashbookGetCashbooksParams

type CashbookGetCashbooksParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookGetCashbooksParams contains all the parameters to send to the API endpoint

for the cashbook get cashbooks operation.

Typically these are written to a http.Request.

func NewCashbookGetCashbooksParams

func NewCashbookGetCashbooksParams() *CashbookGetCashbooksParams

NewCashbookGetCashbooksParams creates a new CashbookGetCashbooksParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookGetCashbooksParamsWithContext

func NewCashbookGetCashbooksParamsWithContext(ctx context.Context) *CashbookGetCashbooksParams

NewCashbookGetCashbooksParamsWithContext creates a new CashbookGetCashbooksParams object with the ability to set a context for a request.

func NewCashbookGetCashbooksParamsWithHTTPClient

func NewCashbookGetCashbooksParamsWithHTTPClient(client *http.Client) *CashbookGetCashbooksParams

NewCashbookGetCashbooksParamsWithHTTPClient creates a new CashbookGetCashbooksParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookGetCashbooksParamsWithTimeout

func NewCashbookGetCashbooksParamsWithTimeout(timeout time.Duration) *CashbookGetCashbooksParams

NewCashbookGetCashbooksParamsWithTimeout creates a new CashbookGetCashbooksParams object with the ability to set a timeout on a request.

func (*CashbookGetCashbooksParams) SetContext

func (o *CashbookGetCashbooksParams) SetContext(ctx context.Context)

SetContext adds the context to the cashbook get cashbooks params

func (*CashbookGetCashbooksParams) SetDefaults

func (o *CashbookGetCashbooksParams) SetDefaults()

SetDefaults hydrates default values in the cashbook get cashbooks params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbooksParams) SetHTTPClient

func (o *CashbookGetCashbooksParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook get cashbooks params

func (*CashbookGetCashbooksParams) SetTimeout

func (o *CashbookGetCashbooksParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook get cashbooks params

func (*CashbookGetCashbooksParams) WithContext

WithContext adds the context to the cashbook get cashbooks params

func (*CashbookGetCashbooksParams) WithDefaults

WithDefaults hydrates default values in the cashbook get cashbooks params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookGetCashbooksParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the cashbook get cashbooks params

func (*CashbookGetCashbooksParams) WithTimeout

WithTimeout adds the timeout to the cashbook get cashbooks params

func (*CashbookGetCashbooksParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookGetCashbooksReader

type CashbookGetCashbooksReader struct {
	// contains filtered or unexported fields
}

CashbookGetCashbooksReader is a Reader for the CashbookGetCashbooks structure.

func (*CashbookGetCashbooksReader) ReadResponse

func (o *CashbookGetCashbooksReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CashbookInitializeCashbookOK

type CashbookInitializeCashbookOK struct {
}

CashbookInitializeCashbookOK describes a response with status code 200, with default header values.

Initialize the cash book for first use

func NewCashbookInitializeCashbookOK

func NewCashbookInitializeCashbookOK() *CashbookInitializeCashbookOK

NewCashbookInitializeCashbookOK creates a CashbookInitializeCashbookOK with default headers values

func (*CashbookInitializeCashbookOK) Code

Code gets the status code for the cashbook initialize cashbook o k response

func (*CashbookInitializeCashbookOK) Error

func (*CashbookInitializeCashbookOK) IsClientError

func (o *CashbookInitializeCashbookOK) IsClientError() bool

IsClientError returns true when this cashbook initialize cashbook o k response has a 4xx status code

func (*CashbookInitializeCashbookOK) IsCode

func (o *CashbookInitializeCashbookOK) IsCode(code int) bool

IsCode returns true when this cashbook initialize cashbook o k response a status code equal to that given

func (*CashbookInitializeCashbookOK) IsRedirect

func (o *CashbookInitializeCashbookOK) IsRedirect() bool

IsRedirect returns true when this cashbook initialize cashbook o k response has a 3xx status code

func (*CashbookInitializeCashbookOK) IsServerError

func (o *CashbookInitializeCashbookOK) IsServerError() bool

IsServerError returns true when this cashbook initialize cashbook o k response has a 5xx status code

func (*CashbookInitializeCashbookOK) IsSuccess

func (o *CashbookInitializeCashbookOK) IsSuccess() bool

IsSuccess returns true when this cashbook initialize cashbook o k response has a 2xx status code

func (*CashbookInitializeCashbookOK) String

type CashbookInitializeCashbookParams

type CashbookInitializeCashbookParams struct {

	// CashbookInitialization.
	CashbookInitialization *model.CashbookInitialization

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookInitializeCashbookParams contains all the parameters to send to the API endpoint

for the cashbook initialize cashbook operation.

Typically these are written to a http.Request.

func NewCashbookInitializeCashbookParams

func NewCashbookInitializeCashbookParams() *CashbookInitializeCashbookParams

NewCashbookInitializeCashbookParams creates a new CashbookInitializeCashbookParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookInitializeCashbookParamsWithContext

func NewCashbookInitializeCashbookParamsWithContext(ctx context.Context) *CashbookInitializeCashbookParams

NewCashbookInitializeCashbookParamsWithContext creates a new CashbookInitializeCashbookParams object with the ability to set a context for a request.

func NewCashbookInitializeCashbookParamsWithHTTPClient

func NewCashbookInitializeCashbookParamsWithHTTPClient(client *http.Client) *CashbookInitializeCashbookParams

NewCashbookInitializeCashbookParamsWithHTTPClient creates a new CashbookInitializeCashbookParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookInitializeCashbookParamsWithTimeout

func NewCashbookInitializeCashbookParamsWithTimeout(timeout time.Duration) *CashbookInitializeCashbookParams

NewCashbookInitializeCashbookParamsWithTimeout creates a new CashbookInitializeCashbookParams object with the ability to set a timeout on a request.

func (*CashbookInitializeCashbookParams) SetCashbookInitialization

func (o *CashbookInitializeCashbookParams) SetCashbookInitialization(cashbookInitialization *model.CashbookInitialization)

SetCashbookInitialization adds the cashbookInitialization to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) SetContext

SetContext adds the context to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) SetDefaults

func (o *CashbookInitializeCashbookParams) SetDefaults()

SetDefaults hydrates default values in the cashbook initialize cashbook params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookInitializeCashbookParams) SetHTTPClient

func (o *CashbookInitializeCashbookParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) SetTimeout

func (o *CashbookInitializeCashbookParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) WithCashbookInitialization

func (o *CashbookInitializeCashbookParams) WithCashbookInitialization(cashbookInitialization *model.CashbookInitialization) *CashbookInitializeCashbookParams

WithCashbookInitialization adds the cashbookInitialization to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) WithContext

WithContext adds the context to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) WithDefaults

WithDefaults hydrates default values in the cashbook initialize cashbook params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookInitializeCashbookParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) WithTimeout

WithTimeout adds the timeout to the cashbook initialize cashbook params

func (*CashbookInitializeCashbookParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookInitializeCashbookReader

type CashbookInitializeCashbookReader struct {
	// contains filtered or unexported fields
}

CashbookInitializeCashbookReader is a Reader for the CashbookInitializeCashbook structure.

func (*CashbookInitializeCashbookReader) ReadResponse

func (o *CashbookInitializeCashbookReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CashbookPostCashbookEntryOK

type CashbookPostCashbookEntryOK struct {
	Payload *model.CashbookEntry
}

CashbookPostCashbookEntryOK describes a response with status code 200, with default header values.

Add an entry to the cash book

func NewCashbookPostCashbookEntryOK

func NewCashbookPostCashbookEntryOK() *CashbookPostCashbookEntryOK

NewCashbookPostCashbookEntryOK creates a CashbookPostCashbookEntryOK with default headers values

func (*CashbookPostCashbookEntryOK) Code

func (o *CashbookPostCashbookEntryOK) Code() int

Code gets the status code for the cashbook post cashbook entry o k response

func (*CashbookPostCashbookEntryOK) Error

func (*CashbookPostCashbookEntryOK) GetPayload

func (*CashbookPostCashbookEntryOK) IsClientError

func (o *CashbookPostCashbookEntryOK) IsClientError() bool

IsClientError returns true when this cashbook post cashbook entry o k response has a 4xx status code

func (*CashbookPostCashbookEntryOK) IsCode

func (o *CashbookPostCashbookEntryOK) IsCode(code int) bool

IsCode returns true when this cashbook post cashbook entry o k response a status code equal to that given

func (*CashbookPostCashbookEntryOK) IsRedirect

func (o *CashbookPostCashbookEntryOK) IsRedirect() bool

IsRedirect returns true when this cashbook post cashbook entry o k response has a 3xx status code

func (*CashbookPostCashbookEntryOK) IsServerError

func (o *CashbookPostCashbookEntryOK) IsServerError() bool

IsServerError returns true when this cashbook post cashbook entry o k response has a 5xx status code

func (*CashbookPostCashbookEntryOK) IsSuccess

func (o *CashbookPostCashbookEntryOK) IsSuccess() bool

IsSuccess returns true when this cashbook post cashbook entry o k response has a 2xx status code

func (*CashbookPostCashbookEntryOK) String

func (o *CashbookPostCashbookEntryOK) String() string

type CashbookPostCashbookEntryParams

type CashbookPostCashbookEntryParams struct {

	// CashbookInputEntry.
	CashbookInputEntry *model.CashbookEntry

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CashbookPostCashbookEntryParams contains all the parameters to send to the API endpoint

for the cashbook post cashbook entry operation.

Typically these are written to a http.Request.

func NewCashbookPostCashbookEntryParams

func NewCashbookPostCashbookEntryParams() *CashbookPostCashbookEntryParams

NewCashbookPostCashbookEntryParams creates a new CashbookPostCashbookEntryParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCashbookPostCashbookEntryParamsWithContext

func NewCashbookPostCashbookEntryParamsWithContext(ctx context.Context) *CashbookPostCashbookEntryParams

NewCashbookPostCashbookEntryParamsWithContext creates a new CashbookPostCashbookEntryParams object with the ability to set a context for a request.

func NewCashbookPostCashbookEntryParamsWithHTTPClient

func NewCashbookPostCashbookEntryParamsWithHTTPClient(client *http.Client) *CashbookPostCashbookEntryParams

NewCashbookPostCashbookEntryParamsWithHTTPClient creates a new CashbookPostCashbookEntryParams object with the ability to set a custom HTTPClient for a request.

func NewCashbookPostCashbookEntryParamsWithTimeout

func NewCashbookPostCashbookEntryParamsWithTimeout(timeout time.Duration) *CashbookPostCashbookEntryParams

NewCashbookPostCashbookEntryParamsWithTimeout creates a new CashbookPostCashbookEntryParams object with the ability to set a timeout on a request.

func (*CashbookPostCashbookEntryParams) SetCashbookInputEntry

func (o *CashbookPostCashbookEntryParams) SetCashbookInputEntry(cashbookInputEntry *model.CashbookEntry)

SetCashbookInputEntry adds the cashbookInputEntry to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) SetContext

func (o *CashbookPostCashbookEntryParams) SetContext(ctx context.Context)

SetContext adds the context to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) SetDefaults

func (o *CashbookPostCashbookEntryParams) SetDefaults()

SetDefaults hydrates default values in the cashbook post cashbook entry params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookPostCashbookEntryParams) SetHTTPClient

func (o *CashbookPostCashbookEntryParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) SetTimeout

func (o *CashbookPostCashbookEntryParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) WithCashbookInputEntry

func (o *CashbookPostCashbookEntryParams) WithCashbookInputEntry(cashbookInputEntry *model.CashbookEntry) *CashbookPostCashbookEntryParams

WithCashbookInputEntry adds the cashbookInputEntry to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) WithContext

WithContext adds the context to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) WithDefaults

WithDefaults hydrates default values in the cashbook post cashbook entry params (not the query body).

All values with no default are reset to their zero value.

func (*CashbookPostCashbookEntryParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) WithTimeout

WithTimeout adds the timeout to the cashbook post cashbook entry params

func (*CashbookPostCashbookEntryParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CashbookPostCashbookEntryReader

type CashbookPostCashbookEntryReader struct {
	// contains filtered or unexported fields
}

CashbookPostCashbookEntryReader is a Reader for the CashbookPostCashbookEntry structure.

func (*CashbookPostCashbookEntryReader) ReadResponse

func (o *CashbookPostCashbookEntryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for cashbook API

func (*Client) CashbookCloseCashbook

func (a *Client) CashbookCloseCashbook(params *CashbookCloseCashbookParams, opts ...ClientOption) (*CashbookCloseCashbookOK, error)

CashbookCloseCashbook initializes the cash book for first use

func (*Client) CashbookGetCashbook

func (a *Client) CashbookGetCashbook(params *CashbookGetCashbookParams, opts ...ClientOption) (*CashbookGetCashbookOK, error)

CashbookGetCashbook gets the current cash book

func (*Client) CashbookGetCashbookEntries

func (a *Client) CashbookGetCashbookEntries(params *CashbookGetCashbookEntriesParams, opts ...ClientOption) (*CashbookGetCashbookEntriesOK, error)

CashbookGetCashbookEntries gets an overview of all the entries in the cash book

func (*Client) CashbookGetCashbookHistory

func (a *Client) CashbookGetCashbookHistory(params *CashbookGetCashbookHistoryParams, opts ...ClientOption) (*CashbookGetCashbookHistoryOK, error)

CashbookGetCashbookHistory gets an overview of all the entries in a closed cash book

func (*Client) CashbookGetCashbooks

func (a *Client) CashbookGetCashbooks(params *CashbookGetCashbooksParams, opts ...ClientOption) (*CashbookGetCashbooksOK, error)

CashbookGetCashbooks gets the current cash book

func (*Client) CashbookInitializeCashbook

func (a *Client) CashbookInitializeCashbook(params *CashbookInitializeCashbookParams, opts ...ClientOption) (*CashbookInitializeCashbookOK, error)

CashbookInitializeCashbook initializes the cash book for first use

func (*Client) CashbookPostCashbookEntry

func (a *Client) CashbookPostCashbookEntry(params *CashbookPostCashbookEntryParams, opts ...ClientOption) (*CashbookPostCashbookEntryOK, error)

CashbookPostCashbookEntry adds an entry to the cash book

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption may be used to customize the behavior of Client methods.

func WithAccept

func WithAccept(mime string) ClientOption

WithAccept allows the client to force the Accept header to negotiate a specific Producer from the server.

You may use this option to set arbitrary extensions to your MIME media type.

func WithContentType

func WithContentType(mime string) ClientOption

WithContentType allows the client to force the Content-Type header to negotiate a specific Consumer from the server.

You may use this option to set arbitrary extensions to your MIME media type.

type ClientService

type ClientService interface {
	CashbookCloseCashbook(params *CashbookCloseCashbookParams, opts ...ClientOption) (*CashbookCloseCashbookOK, error)

	CashbookGetCashbook(params *CashbookGetCashbookParams, opts ...ClientOption) (*CashbookGetCashbookOK, error)

	CashbookGetCashbookEntries(params *CashbookGetCashbookEntriesParams, opts ...ClientOption) (*CashbookGetCashbookEntriesOK, error)

	CashbookGetCashbookHistory(params *CashbookGetCashbookHistoryParams, opts ...ClientOption) (*CashbookGetCashbookHistoryOK, error)

	CashbookGetCashbooks(params *CashbookGetCashbooksParams, opts ...ClientOption) (*CashbookGetCashbooksOK, error)

	CashbookInitializeCashbook(params *CashbookInitializeCashbookParams, opts ...ClientOption) (*CashbookInitializeCashbookOK, error)

	CashbookPostCashbookEntry(params *CashbookPostCashbookEntryParams, opts ...ClientOption) (*CashbookPostCashbookEntryOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new cashbook API client.

func NewClientWithBasicAuth

func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService

New creates a new cashbook API client with basic auth credentials. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.

func NewClientWithBearerToken

func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService

New creates a new cashbook API client with a bearer token for authentication. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.

Jump to